@@ -8,6 +8,7 @@ SAVE_ATTRIBUTES = [('gsd.hints'),
                    ('gsd.auto_fills'),
                    ('timer.__absolute_start_time__'),
                    ('timer.tot_time'),
+                   ('timer.tot_time_complete'),
                    ]
 
 def super_getattr (obj, attr):
@@ -60,6 +61,9 @@ def open_game (ui, jar):
             ui.tracker_ui.select_tracker(tracker)
     for attr in SAVE_ATTRIBUTES:
         super_setattr(ui,attr,jar.get(attr,None))
+    for attr in SAVE_ATTRIBUTES:
+        if jar.get(attr,None) == None:
+            super_setattr(ui,attr,0)
     if jar.has_key('notes') and jar['notes']:
         for x,y,top,bot in jar['notes']:
             ui.gsd.__entries__[(x,y)].set_note_text(top,bot)
@@ -113,11 +117,7 @@ class SudokuTracker:
                         _('Error %(errno)s: %(error)s')%{'errno':e.errno,
                                                          'error':e.strerror}
                         )
-
-    def are_finished_games (self):
-        if os.listdir(self.finished_path): return True
-        else: return False
-
+                        
     def game_from_ui (self, ui):
         return ui.gsd.grid.virgin.to_string()
 
@@ -164,7 +164,7 @@ class SudokuTracker:
                 title=_('Sudoku unable to mark game as finished.'),
                 label=_('Sudoku unable to mark game as finished.'),
                 message_type=gtk.MESSAGE_ERROR,
-                sublabel=(_('Unable to save file %(filename)s.'%locals) + '\n' +
+                sublabel=(_('Unable to save file %(filename)s.')%locals() + '\n' +
                           _('Error %(errno)s: %(error)s')%{
                 'errno':e.errno,
                 'error':e.strerror
@@ -182,7 +182,7 @@ class SudokuTracker:
                 title=_('Sudoku unable to mark game as finished.'),
                 label=_('Sudoku unable to mark game as finished.'),
                 message_type=gtk.MESSAGE_ERROR,
-                sublabel=(_('Unable to save file %(filename)s.'%locals) + '\n' +
+                sublabel=(_('Unable to save file %(filename)s.')%locals() + '\n' +
                           _('Error %(errno)s: %(error)s')%{
                 'errno':e.errno,
                 'error':e.strerror
@@ -202,7 +202,10 @@ class SudokuTracker:
         self.remove_from_saved_games(jar)
         
     def list_saved_games (self):
-        files = os.listdir(self.save_path)
+        try:
+            files = os.listdir(self.save_path)
+        except OSError, e:
+            files = []
         games = []
         for f in files:
             f = os.path.join(self.save_path,f)
