@@ -244,6 +244,12 @@ gtk_minefield_setup_signs (GtkMineField * mfield)
     gtk_widget_show (warning_dialog);
   }
 
+  g_free(flagfile);
+  g_free(minefile);
+  g_free(questionfile);
+  g_free(bangfile);
+  g_free(warningfile);
+
 }
 
 static void
